/* ********************************************************************
 * Universal Currency Converter - An AJAX interface to XE.com
 *  Copyright (c) 2010 - Brian Huisman AKA GreyWyvern/Orca
 *  Released under the BSD licence: http://www.greywyvern.com/code/bsd
 *   or see "licence.txt" included in this package
 *
 * v1.4  - May 26, 2010
 *    - Fixes for updated Opera widget security specification
 *    - Updated for code changes at xe.com
 *    - New icons
 *
 * v1.3  - June 30, 2009
 *    - Pressing Enter in the amount box performs a convert operation
 *
 * v1.2  - April 22, 2009
 *    - Interface and code redesign
 *    - No longer requires contacting greywyvern.com for currency list
 *    - Networking XML update for Opera 10
 *
 * v1.1  - May 16, 2008
 *    - Fix for new my.opera file hotlink protection
 *
 * v1.0e - September 10, 2007
 *    - Adjusted algorithm for xe.com code changes
 *
 * v1.0d - July 19, 2007
 *    - Fix for new my.opera files location "storage9"
 *
 * v1.0c - March 8, 2007
 *    - Adjusted algorithm for xe.com new site design
 *
 * v1.0b - November 6, 2006
 *    - Fixed some currency selection errors on config switch
 *    - Currency list stored at files.opera instead of greywyvern.com
 *
 * v1.0a - October 3, 2006
 *    - Added an "Inverse" button
 *    - Added throbber on submit
 *    - Remembers what currencies you have selected
 *
 * v1.0  - October 2, 2006
 ******************************************************************* */
window.addEventListener("load", function(e) {
  (function CurrencyConverter() {
    var self = this;

    this.currencies = {
      'AFN': "Afghanistan Afghanis",         'ALL': "Albania Leke",                 'DZD': "Algeria Dinars",
      'ARS': "Argentina Pesos",              'AMD': "Armenia Drams",                'AUD': "Australia Dollars",
      'ATS': "Austria Schillings",           'BSD': "Bahamas Dollars",              'BHD': "Bahrain Dinars",
      'BDT': "Bangladesh Taka",              'BBD': "Barbados Dollars",             'BEF': "Belgium Francs",
      'BMD': "Bermuda Dollars",              'BWP': "Botswana Pulas",               'BRL': "Brazil Reais",
      'BGN': "Bulgaria Leva",                'CAD': "Canada Dollars",               'XOF': "CFA BCEAO Francs",
      'XAF': "CFA BEAC Francs",              'CLP': "Chile Pesos",                  'CNY': "China Yuan Renminbi",
      'COP': "Colombia Pesos",               'XPF': "CFP Francs",                   'CRC': "Costa Rica Colones",
      'HRK': "Croatia Kuna",                 'CYP': "Cyprus Pounds",                'CZK': "Czech Republic Koruny",
      'DKK': "Denmark Kroner",               'DOP': "Dominican Republic Pesos",     'XCD': "Eastern Caribbean Dollars",
      'EGP': "Egypt Pounds",                 'EEK': "Estonia Krooni",               'EUR': "Euro",
      'FJD': "Fiji Dollars",                 'FIM': "Finland Markkaa",              'FRF': "France Francs",
      'DEM': "Germany Deutsche Marks",       'XAU': "Gold Ounces",                  'GRD': "Greece Drachmae",
      'HKD': "Hong Kong Dollars",            'HUF': "Hungary Forint",               'ISK': "Iceland Kronur",
      'XDR': "IMF Special Drawing Right",    'INR': "India Rupees",                 'IDR': "Indonesia Rupiahs",
      'IRR': "Iran Rials",                   'IQD': "Iraq Dinars",                  'IEP': "Ireland Pounds",
      'ILS': "Israel New Shekels",           'ITL': "Italy Lire",                   'JMD': "Jamaica Dollars",
      'JPY': "Japan Yen",                    'JOD': "Jordan Dinars",                'KES': "Kenya Shillings",
      'KWD': "Kuwait Dinars",                'LBP': "Lebanon Pounds",               'LUF': "Luxembourg Francs",
      'MYR': "Malaysia Ringgits",            'MTL': "Malta Liri",                   'MUR': "Mauritius Rupees",
      'MXN': "Mexico Pesos",                 'MAD': "Morocco Dirhams",              'NLG': "Netherlands Guilders",
      'NZD': "New Zealand Dollars",          'NOK': "Norway Kroner",                'OMR': "Oman Rials",
      'PKR': "Pakistan Rupees",              'XPD': "Palladium Ounces",             'PEN': "Peru Nuevos Soles",
      'PHP': "Philippines Pesos",            'XPT': "Platinum Ounces",              'PLN': "Poland Zlotych",
      'PTE': "Portugal Escudos",             'QAR': "Qatar Riyals",                 'RON': "Romania New Lei",
      'ROL': "Romania Lei",                  'RUB': "Russia Rubles",                'SAR': "Saudi Arabia Riyals",
      'CSD': "Serbia Dinars",                'XAG': "Silver Ounces",                'SGD': "Singapore Dollars",
      'SKK': "Slovakia Koruny",              'SIT': "Slovenia Tolars",              'ZAR': "South Africa Rand",
      'KRW': "South Korea Won",              'ESP': "Spain Pesetas",                'LKR': "Sri Lanka Rupees",
      'SDD': "Sudan Dinars",                 'SEK': "Sweden Kronor",                'CHF': "Switzerland Francs",
      'TWD': "Taiwan New Dollars",           'THB': "Thailand Baht",                'TTD': "Trinidad and Tobago Dollars",
      'TND': "Tunisia Dinars",               'TRY': "Turkey New Lira",              'UAH': "Ukraine Hryvna",
      'AED': "United Arab Emirates Dirhams", 'GBP': "United Kingdom Pounds",        'USD': "United States Dollars",
      'UYU': "Uruguay Pesos",                'VEB': "Venezuela Bolivares",          'VND': "Vietnam Dong",
      'ZMK': "Zambia Kwacha"
    };
    this.checked = [
      "AUD", "CAD", "CHF", "CNY", "DKK", "EUR", "GBP",
      "HKD", "HUF", "INR", "JPY", "MXN", "MYR", "NOK",
      "NZD", "RUB", "SEK", "SGD", "THB", "USD", "ZAR"
    ];

    this.http = new XMLHttpRequest();

    this.unit = [
      document.getElementsByName('frombox')[0],
      document.getElementsByName('tobox')[0]
    ];  
    this.unit[0].onchange = this.unit[1].onchange = function() {
      if (widget) widget.setPreferenceForKey(this.value, this.name);
    };

    this.amount = document.getElementsByName('amount')[0];
    this.amount.onkeyup = function(e) {
      if ((e || event).keyCode == 13) self.nrmlconvert.onclick();
    };

    this.result = document.getElementById('result');
    this.cover = document.getElementById('cover');
    this.config = document.getElementById('config');

    this.nrmlconvert = document.getElementById('nrmlconvert');
    nrmlconvert.onclick = function() {
      self.result.firstChild.nodeValue = "\u2013";
      if (self.unit[0].value != self.unit[1].value) self.convert();
    };
    document.getElementById('swapconvert').onclick = function() {
      self.result.firstChild.nodeValue = "\u2013";
      var dummy = self.unit[0].value;
      self.unit[0].value = self.unit[1].value;
      self.unit[1].value = dummy;
      self.nrmlconvert.onclick();
    };
    document.getElementById('clear').onclick = function() {
      self.result.firstChild.nodeValue = "\u2013";
      self.amount.value = 1;
    };

    document.getElementById('showconfig').onclick = function() {
      self.toggleConfig();
    };


    /* ****************************************************************
     * Request a conversion from the XE.com server
     *
     */
    this.convert = function() {
      this.amount.value = parseFloat(this.amount.value) || 0;

      if (this.amount.value) {
        this.result.firstChild.nodeValue = "\xa0";
        this.cover.style.visibility = "visible";

        this.http.open("POST", "http://www.xe.com/ucc/convert.cgi", true);
        this.http.setRequestHeader("Content-Type", "application/x-www-form-urlencoded");
        this.http.onreadystatechange = function() {
          if (self.http.readyState == 4) {
            self.cover.style.visibility = "hidden";
            if (self.http.responseText) {
              for (var x = 0, match = self.http.responseText.match(/<td\s+align="(right|left)"\s+class="rate"\s*>[\d.,]+ .../g); x < 2; x++)
                match[x] = match[x].replace(/<td\s+align="(right|left)"\s+class="rate"\s*>/g, "");
              self.result.firstChild.nodeValue = match[1];
            } else self.result.firstChild.nodeValue = "Error!";
          }
        };
        this.http.send("From=" + this.unit[0].value + "&To=" + this.unit[1].value + "&Amount=" + encodeURI(this.amount.value) + "&submit=submit");
      }
    };

    /* ****************************************************************
     * Toggle the config list
     *
     */
    this.toggleConfig = function() {
      if (this.config.style.visibility != "visible") {
        this.config.style.visibility = "visible";
      } else {
        self.result.firstChild.nodeValue = "\u2013";
        var selected = [this.unit[0].value, this.unit[1].value];
        this.refreshCurrencies();

        for (var x = 0; x < 2; x++)
          if ((this.unit[x].value = selected[x]) != selected[x])
            this.unit[x].selectedIndex = 0;
        this.config.style.visibility = "hidden";
      }
    };


    /* ****************************************************************
     * Rebuild the currency dropdowns based on the config list
     *
     */
    this.refreshCurrencies = function() {
      for (var x = 0; x < 2; x++)
        while (this.unit[x].childNodes.length) this.unit[x].removeChild(this.unit[x].firstChild);

      for (var x = 0, cur = this.config.getElementsByTagName('input'), wp = [], box; box = cur[x++];) {
        if (box.checked) {
          var option = document.createElement('option');
              option.value = box.value;
              option.appendChild(document.createTextNode(this.currencies[box.value]));
          this.unit[0].appendChild(option.cloneNode(true));
          this.unit[1].appendChild(option);
          wp.push(box.value);
        }
      } if (widget) widget.setPreferenceForKey(wp.join(" "), 'currencies');
    };



    // ***** Initialise the widget
    if (widget && widget.preferenceForKey('currencies'))
      this.checked = widget.preferenceForKey('currencies').split(" ");

    var ul = this.config.getElementsByTagName('ul')[0];
    for (code in this.currencies) {
      var li = document.createElement('li');
        var label = document.createElement('label');
          var input = document.createElement('input');
              input.type = "checkbox";
              input.value = code;
            for (var y = 0; y < this.checked.length; y++) {
              if (this.checked[y] == code) {
                  input.checked = "checked";
                break;
              }
            }
            label.appendChild(input);
            label.appendChild(document.createTextNode(" " + this.currencies[code] + " (" + code + ")"));
          li.appendChild(label);
        ul.appendChild(li);
    }

    this.refreshCurrencies();
    for (var x = 0; x < 2; x++)
      if (widget && widget.preferenceForKey(this.unit[x].name))
        this.unit[x].value = widget.preferenceForKey(this.unit[x].name);

    this.cover.style.visibility = "hidden";
  })();
}, false);